@@ -27,11 +27,25 @@
 
 #include <config.h>
 #include <gnome.h>
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+#ifdef __FreeBSD__
+#include <dirent.h>
+#endif
+#if defined HAVE_SYS_DIRENT_H
+#include <sys/dirent.h>
+#endif
 #ifdef HAVE_SYS_DIR_H
 #include <sys/dir.h>
 #else
 #include <dirent.h>
 #endif
+
+#ifdef __osf__
+#undef HAVE_STRUCT_DIRECT
+#endif
+
 #include <gdk-card-image.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <libgnomevfs/gnome-vfs.h>
